@@ -1,21 +1,22 @@
 #!/bin/bash
-# Copyright (c) 2005/6 Andreas Mair
+# vim:noet:sw=4:ts=4:
+# Copyright (c) 2005-2014 Andreas Mair
 #
 #
 # Download and patchscript for VDRAdmin-AM
 # (based on install.sh Copyright (c) 2003 Frank (xpix) Herrmann)
 
 PATH=$PATH:/sbin:/bin:/usr/sbin:/usr/bin
-DESTDIR=${DESTDIR}
-LIBDIR=${LIBDIR:-$DESTDIR/usr/share/vdradmin}
-ETCDIR=${ETCDIR:-$DESTDIR/etc/vdradmin}
-DOCDIR=${DOCDIR:-$DESTDIR/usr/share/doc/vdradmin}
-BINDIR=${BINDIR:-$DESTDIR/usr/bin}
-LOCDIR=${LOCDIR:-$DESTDIR/usr/share/locale}
-MANDIR=${MANDIR:-$DESTDIR/usr/share/man/man1}
-LOGDIR=${LOGDIR:-$DESTDIR/var/log}
-CACHEDIR=${CACHEDIR:-$DESTDIR/var/cache/vdradmin}
-PIDFILE=${PIDFILE:-$DESTDIR/var/run/vdradmind.pid}
+PREFIX=${PREFIX}
+LIBDIR=${LIBDIR:-$PREFIX/usr/share/vdradmin}
+ETCDIR=${ETCDIR:-$PREFIX/etc/vdradmin}
+DOCDIR=${DOCDIR:-$PREFIX/usr/share/doc/vdradmin}
+BINDIR=${BINDIR:-$PREFIX/usr/bin}
+LOCDIR=${LOCDIR:-$PREFIX/usr/share/locale}
+MANDIR=${MANDIR:-$PREFIX/usr/share/man}
+LOGDIR=${LOGDIR:-$PREFIX/var/log/vdradmin}
+CACHEDIR=${CACHEDIR:-$PREFIX/var/cache/vdradmin}
+PIDFILE=${PIDFILE:-$PREFIX/var/run/vdradmin/vdradmind.pid}
 VIDEODIR=${VIDEODIR:-/video}
 EPGIMAGES=${EPGIMAGES:-$VIDEODIR/epgimages}
 VDRCONF=${VDRCONF:-$VIDEODIR}
@@ -69,7 +70,6 @@ function checkPerlModule()
 	else
 		echo " found"
 	fi
-
 }
 
 function perlModules()
@@ -77,7 +77,6 @@ function perlModules()
 	echo ""
 	echo "*** Required ***"
 	checkPerlModule locale
-	checkPerlModule Env
 	checkPerlModule Template
 	checkPerlModule Template::Plugin::JavaScript
 	checkPerlModule CGI
@@ -86,7 +85,11 @@ function perlModules()
 	checkPerlModule Time::Local
 	checkPerlModule MIME::Base64
 	checkPerlModule File::Temp
+	checkPerlModule File::Find
+	checkPerlModule URI
 	checkPerlModule URI::Escape
+	checkPerlModule HTTP::Tiny
+	checkPerlModule HTTP::Daemon
 
 
 	echo ""
@@ -105,7 +108,7 @@ function perlModules()
 	echo "* Required for IPv6 support"
 	checkPerlModule IO::Socket::INET6
 	echo "* Required for SSL support (https)"
-	checkPerlModule IO::Socket::SSL
+	checkPerlModule HTTP::Daemon::SSL
 	echo "* Required if you want to use gzip'ed HTTP responses"
 	checkPerlModule Compress::Zlib
 	echo "* Required if you want to log to syslog"
@@ -147,9 +150,9 @@ function doInstall()
 	perlModules
 
 	makeDir $LIBDIR 1 && cp -r template lib $LIBDIR || exit 1
-  makeDir $DOCDIR && cp -r contrib COPYING CREDITS HISTORY INSTALL LGPL.txt README* REQUIREMENTS FAQ $DOCDIR || exit 1
-	makeDir $MANDIR && cp vdradmind.pl.1 $MANDIR/vdradmind.1 || exit 1
-	makeDir $ETCDIR || exit 1
+	makeDir $BINDIR || exit 1
+	makeDir $DOCDIR && cp -r contrib COPYING CREDITS HISTORY INSTALL LGPL.txt README* REQUIREMENTS FAQ $DOCDIR || exit 1
+	makeDir $MANDIR/man8 && cp vdradmind.pl.1 $MANDIR/man8/vdradmind.8 || exit 1
 
 	(
 		cd locale
@@ -160,47 +163,48 @@ function doInstall()
 	)
 
 	local RESTART=
-	[ ! -e $BINDIR ] && mkdir -p $BINDIR
 	if [ -d $BINDIR ]; then
 		killRunningVDRAdmin
 		if [ $? -ne 0 ] ; then
 			RESTART=1
-  		echo "Killed running VDRAdmin-AM..."
-  	fi
-  	sed <vdradmind.pl >$BINDIR/vdradmind \
-  	    -e "s/^\(my \$SEARCH_FILES_IN_SYSTEM *=\) 0;/\1 1;/" \
-  	    -e "s:/usr/share/vdradmin/lib:${LIBDIR}/lib:" \
-  	    -e "s:/usr/share/vdradmin/template:${LIBDIR}/template:" \
-  	    -e "s:/var/log:${LOGDIR}:" \
-  	    -e "s:/var/cache/vdradmin:${CACHEDIR}:" \
-  	    -e "s:/var/run/vdradmind.pid:${PIDFILE}:" \
-  	    -e "s:\(\$ETCDIR *= \)\"/etc/vdradmin\";:\1\"${ETCDIR}\";:" \
-  	    -e "s:/usr/share/locale:${LOCDIR}:" \
-  	    -e "s:\(\$CONFIG{VIDEODIR} *= \)\"/video\";:\1\"${VIDEODIR}\";:" \
-  	    -e "s:\(\$CONFIG{EPGIMAGES} *= \)\"\$CONFIG{VIDEODIR}/epgimages\";:\1\"${EPGIMAGES}\";:" \
+			echo "Killed running VDRAdmin-AM..."
+		fi
+		sed <vdradmind.pl >$BINDIR/vdradmind \
+		    -e "s/^\(my \$SEARCH_FILES_IN_SYSTEM *=\) 0;/\1 1;/" \
+		    -e "s:/usr/share/vdradmin/lib:${LIBDIR}/lib:" \
+		    -e "s:/usr/share/vdradmin/template:${LIBDIR}/template:" \
+		   -e "s:/var/log/vdradmin:${LOGDIR}:" \
+		    -e "s:/var/cache/vdradmin:${CACHEDIR}:" \
+		    -e "s:/var/run/vdradmin/vdradmind.pid:${PIDFILE}:" \
+		    -e "s:\(\$ETCDIR *= \)\"/etc/vdradmin\";:\1\"${ETCDIR}\";:" \
+		    -e "s:/usr/share/locale:${LOCDIR}:" \
+		    -e "s:\(\$CONFIG{VIDEODIR} *= \)\"/video\";:\1\"${VIDEODIR}\";:" \
+		    -e "s:\(\$CONFIG{EPGIMAGES} *= \)\"\$CONFIG{VIDEODIR}/epgimages\";:\1\"${EPGIMAGES}\";:" \
 				-e "s:\(\$CONFIG{VDRCONFDIR} *= \)\"\$CONFIG{VIDEODIR}\";:\1\"${VDRCONF}\";:"
 
 		chmod a+x  $BINDIR/vdradmind
 
-  	if [ "$CONFIG" ]; then
-    	echo "Configuring VDRAdmin-AM..."
-    	$BINDIR/vdradmind -c
-  	fi
+		if [ "$CONFIG" ]; then
+			echo "Configuring VDRAdmin-AM..."
+			$BINDIR/vdradmind -c
+		fi
 
-  	if [ "$RESTART" ]; then
-  		echo "Restarting VDRAdmin-AM..."
-  		$BINDIR/vdradmind
-  	fi
+		if [ "$RESTART" ]; then
+			echo "Restarting VDRAdmin-AM..."
+			$BINDIR/vdradmind
+		fi
 
 		echo ""
 		if [ -e $BINDIR/vdradmind.pl ]; then
 			echo "Removing ancient $BINDIR/vdradmind.pl"
 			rm -f $BINDIR/vdradmind.pl
 		fi
-		if [ -e $MANDIR/vdradmind.pl.1 ]; then
-			echo "Removing ancient $MANDIR/vdradmind.pl.1"
-			rm -f $MANDIR/vdradmind.pl.1
-		fi
+		for man in man1/vdradmind.pl.1 man1/vdradmind.1; do
+			if [ -e $MANDIR/$man ]; then
+				echo "Removing ancient $MANDIR/$man"
+				rm -f $MANDIR/$man
+			fi
+		done
 	else
 		echo "$BINDIR exists but is no directory!"
 		echo "Aborting..."
@@ -220,6 +224,14 @@ function doInstall()
 	echo ""
 	echo "NOTE2:"
 	echo "If you would like VDRAdmin-AM to start at system's boot, please modify your system's init scripts."
+
+	local USED_DIRS="$(echo -e "$ETCDIR\n$LOGDIR\n$CACHEDIR\n$(dirname "$PIDFILE")" | sort -u)"
+	echo
+	echo "NOTE3:"
+	echo "VDRAdmin-AM needs to access some directories:"
+	echo "$USED_DIRS"
+	echo
+	echo "Please check that the user VDRAdmin-AM runs has enough permissions to access them!"
 	exit 0
 }
 
@@ -239,12 +251,11 @@ function doUninstall()
 	if [ -d $CACHEDIR ]; then
 		rm -rf $CACHEDIR
 	fi
-	if [ -e $MANDIR/vdradmind.pl.1 ]; then
-		rm -f $MANDIR/vdradmind.pl.1
-	fi
-	if [ -e $MANDIR/vdradmind.1 ]; then
-		rm -f $MANDIR/vdradmind.1
-	fi
+	for man in man1/vdradmind.pl.1 man1/vdradmind.1 man8/vdradmind.8; do
+		if [ -e $MANDIR/$man ]; then
+			rm -f $MANDIR/$man
+		fi
+	done
 	if [ -e $BINDIR/vdradmind.pl ]; then
 		rm -f $BINDIR/vdradmind.pl
 	fi
